<template>
  <div class="app-container">
    <div class="filter-container">
      <el-input
        :disabled="disabled"
        v-model="listQuery.searchname"
        placeholder="输入产品搜索"
        style="width: 200px;"
        class="filter-item"
        @change="handleFilter"
        clearable
        @keyup.enter.native="handleFilter"
      />
      <el-button class="filter-item" style="margin-left: 10px;" type="primary" icon="el-icon-search" @click="handleFilter">{{ $t('common.search') }}</el-button>
      <el-button class="filter-item" style="margin-left: 2px;" type="primary" icon="el-icon-edit" @click="handleAdd">{{ $t('common.add') }}</el-button>
    </div>

    <el-table stripe :data="list" border fit style="width: 80%">
      <el-table-column label="序号" type="index" align="center" width="60">
        <template slot-scope="scope">
          <span>{{ scope.$index + 1 + (listQuery.page - 1) * 10 }}</span>
        </template>
      </el-table-column>
      <el-table-column label="产品名称" align="center" width="100">
        <template slot-scope="scope">
          <span>{{ scope.row.product }}</span>
        </template>
      </el-table-column>
      <el-table-column label="地区" align="center" width="200">
        <template slot-scope="scope">
          <span>{{ scope.row.address }}</span>
        </template>
      </el-table-column>
      <el-table-column label="需求描述" align="center" width="200">
        <template slot-scope="scope">
          <span>{{ scope.row.assessmentDescribe }}</span>
        </template>
      </el-table-column>
      <el-table-column label="照片" align="center">
        <template slot-scope="scope">
          <img :src="'/api/file/'+scope.row.assessmentImgUrl" style="height: 40px;width: 100px" />
        </template>
      </el-table-column>
      <el-table-column label="时间" align="center">
        <template slot-scope="scope">
          <span>{{ scope.row.assessmentTime }}</span>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" width="200">
        <template slot-scope="scope">
          <el-button size="mini" type="primary" @click="handleEdit(scope.$index, scope.row)">{{ $t('common.edit') }}</el-button>
          <el-button size="mini" type="danger" @click="handleDelete(scope.$index, scope.row)">{{ $t('common.delete') }}</el-button>
        </template>
      </el-table-column>
    </el-table>

    <el-dialog
      :close-on-click-modal="false"
      :destroy-on-close="true"
      :title="disabled ? '查看信息' : dialogState === 1 ? '填写信息' : '修改信息'"
      :visible.sync="dialogVisible"
      width="30%"
      :before-close="handleClose"
    >
      <el-form ref="dialogform" :model="form" :rules="rules" label-width="80px">
        <el-form-item prop="product" label="产品名称">
          <el-input :disabled="disabled" v-model="form.product"></el-input>
        </el-form-item>
        <el-form-item prop="address" label="地区">
          <el-input :disabled="disabled" v-model="form.address"></el-input>
        </el-form-item>
        <el-form-item prop="assessmentDescribe" label="需求描述">
          <el-input :disabled="disabled" v-model="form.assessmentDescribe"></el-input>
        </el-form-item>
        <el-form-item prop="assessmentImgUrl" label="照片">
          <Uploader ref="child"  v-bind:url="fileUrl"
                    v-bind:name="fileName" v-on:uploadSuccess="uploadSuccess" style="width: 100%"></Uploader>
        </el-form-item>
        <el-form-item prop="assessmentTime" label="新闻时间">
          <el-date-picker
            :disabled="disabled"
            v-model="form.assessmentTime"
            value-format="yyyy-MM-dd HH:mm:ss"
            type="datetime"
            placeholder="选择日期时间">
          </el-date-picker>
        </el-form-item>
        <el-form-item align="center" label-width="0">
          <el-button type="primary" @click="onSubmit(form)">{{ dialogState === 1 ? $t('common.add') : $t('common.save') }}</el-button>
          <el-button :style="disabled ? 'display:none' : ''" @click="dialogVisible = false">{{ $t('common.cancel') }}</el-button>
        </el-form-item>
      </el-form>
    </el-dialog>

    <pagination v-show="total > 0" :total="total" :page.sync="listQuery.page" :limit.sync="listQuery.limit" @pagination="fetchList" />
  </div>
</template>

<script>
import { getAllAssessment, addAssessment, updateAssessment, deleteAssessmentById, getAssessmentById } from '@/api/assessment';
import Pagination from '@/components/Pagination';
import Uploader from '@/components/Uploader2';
import download from '@/api/uploadUrl';

export default {
  components: { Pagination,Uploader },
  data() {
    return {
      fileUrl:"",
      fileName:'',
      download: download,
      disabled: false,
      total: 0,
      list: [],
      listQuery: {
        searchname: '',
        page: 1,
        limit: 10
      },
      dialogState: 1, //1:add, 2:edit
      dialogVisible: false,
      form: {
        product: '',
        address: '',
        assessmentDescribe: '',
        assessmentTime: '',
        assessmentImgUrl: ''
      },
      rules: {
        product: [{ required: true, message: '产品不能为空', trigvalueger: 'blur' }],
        address: [{ required: true, message: '地区不能为空', trigger: 'blur' }],
        assessmentDescribe: [{ required: true, message: '描述不能为空', trigvalueger: 'blur' }],
        assessmentTime: [{ required: true, message: '时间不能为空', trigger: 'blur' }],
        assessmentImgUrl: [{ required: true, message: '照片不能为空', trigger: 'blur' }]
      },
      dialogImageUrl: '',
      dialogVisibleImg: false,
      disabledImg: false
    };
  },
  mounted() {
    this.fetchList();
  },
  methods: {
    uploadSuccess(data) {
      this.form.assessmentImgUrl = data.fileUrl;
      this.form.fileName=data.fileName
      console.log(this.form)
    },
    handleView(id) {
      this.handleEdit(id);
      this.disabled = true;
    },
    async fetchList() {
      const res = await getAllAssessment(this.listQuery);
      if (res && res.result) {
        console.log(res)
        this.total = res.data.total;
        this.list = res.data.list;
      }
    },

    handleFilter() {
      this.listQuery.page = 1;
      this.fetchList();
    },
    handleAdd() {
      this.form = {
        product: '',
        address: '',
        assessmentDescribe: '',
        assessmentTime: '',
        assessmentImgUrl: ''
      };
      this.dialogState = 1;
      this.dialogVisible = true;
    },
    async handleEdit(index, row) {
      this.dialogState = 2;
      this.form = deepClone(row);
      const res = await getAssessmentById(row.id);
      if (res && res.result) {
        this.dialogVisible = true;
        this.fileUrl=res.data.assessmentImgUrl
        var name = this.fileUrl.split('/')[1]
        this.fileName=name
      }
    },
    handleDelete(index, row) {
      console.log(index, row);
      const _this = this;
      this.$confirm(this.$t('message.delete_confirm'), this.$t('common.tip'), {
        confirmButtonText: this.$t('common.ok'),
        cancelButtonText: this.$t('common.cancel'),
        type: 'warning'
      })
        .then(() => {
          deleteAssessmentById(row.id).then(res => {
            if (res.result) {
              this.$message(this.$t('message.delete_success'), 'success');
              this.fetchList();
            } else {
              this.$message(this.$t('message.delete_fail'), 'error');
            }
          });
        })
        .catch(error => {});
    },
    handleClose(done) {
      done();
    },
    onSubmit() {
      this.$refs.dialogform.validate(valid => {
        if (!valid) {
          this.$message('填写的信息有误，请确认', 'error');
          return;
        }

        if (this.dialogState === 1) {
          const data = Object.assign(this.form);
          console.log(data)
          addAssessment(data)
            .then(res => {
              if (!res.result) {
                this.$message(res.errorMsg || this.$t('message.add_fail'), 'error');
                return;
              }
              this.$message(this.$t('message.add_success'), 'success');
              this.fetchList();
              this.dialogVisible = false;
            })
            .catch(error => {});
        } else {
          console.log('updataform',this.form)
          updateAssessment(this.form)
            .then(res => {
              if (!res.result) {
                this.$message(res.errorMsg || this.$t('message.edit_fail'), 'error');
                return;
              }
              this.$message(this.$t('message.edit_success'), 'success');
              this.fetchList();
              this.dialogVisible = false;
            })
            .catch(error => {});
        }
      });
    }
  }
};
</script>
